# 3 Explanation on pedantry

`load` and `dump` have two modes of operation: pedantic and non-pedantic.

- On `load`, the pedantic argument indicates whether the function should bail out on un-loadable constructs instead or just ignore them. Default is not to be pedantic on load.

- On `dump`, the pedantic argument indicates if the function should bail out when dumping objects that could only be partially restored later on (because they belong to a derivate class of a supported type). A successfully dump will always be re-loadable anyway regardless of the pedantry. Default is to be pedantic on dump.

A non-pedantic load or dump does not ensure that the operation will not raise an exception (such as a `SyntaxError` because of an unparsable buffer during a load), only that the level of tolerance to the minor problems just described will be greater.